==> haskell-abstract-par-0.3.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-abstract-par.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: abstract-par
version: 0.3.3
id: abstract-par-0.3.3-5IZBJH84Xee8CclC3iNYtW
key: abstract-par-0.3.3-5IZBJH84Xee8CclC3iNYtW
license: BSD3
copyright: (c) Ryan Newton 2011-2012
maintainer: Ryan Newton <rrnewton@gmail.com>
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: Type classes generalizing the functionality of the '\''monad-par'\'' library.
description:
    The '\''Par'\'' monad offers a parallel programming API based on dataflow
    programming.  To use the `Par` monad, install the @monad-par@
    package, which includes this package as a dependency.
    .
    This package is an abstract interface only. It provides a number of
    type clasess, but not an implementation.  The type classes separate
    different levels of @Par@ functionality.  See the
    "Control.Monad.Par.Class" module for more details.
category: Control,Parallelism,Monads
author: Ryan Newton
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Par.Class Control.Monad.Par.Unsafe
abi: a265ce091bbfcea0c9b2362c53b8a5e8
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/abstract-par-0.3.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/abstract-par-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/abstract-par-0.3.3
hs-libraries: HSabstract-par-0.3.3-5IZBJH84Xee8CclC3iNYtW
depends:
    base-4.10.0.0 deepseq-1.4.3.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             deepseq-1.4.3.0=15f2832424b38ea5b23f1ebc9071dcc3
haddock-interfaces: /usr/share/doc/haskell-abstract-par/html/abstract-par.haddock
haddock-html: /usr/share/doc/haskell-abstract-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-abstract-par-0.3.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-abstract-par.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: abstract-par
version: 0.3.3
id: abstract-par-0.3.3-34FTxNhMsvaFqPXytGYk6c
key: abstract-par-0.3.3-34FTxNhMsvaFqPXytGYk6c
license: BSD3
copyright: (c) Ryan Newton 2011-2012
maintainer: Ryan Newton <rrnewton@gmail.com>
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: Type classes generalizing the functionality of the '\''monad-par'\'' library.
description:
    The '\''Par'\'' monad offers a parallel programming API based on dataflow
    programming.  To use the `Par` monad, install the @monad-par@
    package, which includes this package as a dependency.
    .
    This package is an abstract interface only. It provides a number of
    type clasess, but not an implementation.  The type classes separate
    different levels of @Par@ functionality.  See the
    "Control.Monad.Par.Class" module for more details.
category: Control,Parallelism,Monads
author: Ryan Newton
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Par.Class Control.Monad.Par.Unsafe
abi: 3244c57c239e3b2973c639ecee30ef29
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/abstract-par-0.3.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/abstract-par-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/abstract-par-0.3.3
hs-libraries: HSabstract-par-0.3.3-34FTxNhMsvaFqPXytGYk6c
depends:
    base-4.10.1.0 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-abstract-par/html/abstract-par.haddock
haddock-html: /usr/share/doc/haskell-abstract-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
